@@ -65,15 +65,13 @@ public:
 protected:
     void paintEvent(QPaintEvent *event) override;
     bool eventFilter(QObject *o, QEvent *e) override;
-
-
+    void focusInEvent(QFocusEvent *event) override;
+    void focusOutEvent(QFocusEvent *event) override;
 signals:
     void cutSizeChanged(const QSize &sz);
     void cutTypeChanged(ECutType tp);
     void finshed(bool accept);
 
-
-
 public slots:
     /**
      * @brief changeButtonTheme 根据主题改变按钮主题
@@ -118,7 +116,6 @@ private:
     QWidget     *m_sizeWidget;
     QHBoxLayout *m_sizeLayout;
 
-
 private:
     /**
      * @brief initUI 初始化ＵＩ
