@@ -276,9 +276,13 @@ void ColorPanel::initConnection()
 //    });
 
     //5.设置透明度
-    connect(m_alphaControlWidget, &CAlphaControlWidget::alphaChanged, this, [ = ](int apl, EChangedPhase phase) {
+    connect(m_alphaControlWidget, &CAlphaControlWidget::alphaChanged, this, [ = ](int alp, EChangedPhase phase) {
         QColor c = color();
-        c.setAlpha(apl);
+        if (!c.isValid()) {
+            c = QColor(0, 0, 0, alp);
+        } else {
+            c.setAlpha(alp);
+        }
         qDebug() << "alphaChanged apl = " << c.alpha();
         this->setColor(c, true, phase);
     });
@@ -327,7 +331,9 @@ void ColorPanel::setExpandWidgetVisble(bool visble)
 
 void ColorPanel::updateColor(const QColor &previewColor)
 {
-    QColor c = previewColor.isValid() ? previewColor : curColor;
+    //BUG118771 https://pms.uniontech.com/bug-view-118771.html
+    //QColor c = previewColor.isValid() ? previewColor : curColor;
+    QColor c = previewColor.isValid() ? previewColor : (curColor.isValid() ? curColor : previewColor);
 
     //1.检查当前颜色是否是颜色组的颜色值
     int id = m_colList.indexOf(/*curColor*/QColor(curColor.red(), curColor.green(), curColor.blue()));
