@@ -68,6 +68,10 @@
 #include <QTextEdit>
 #include <QClipboard>
 #include <QCheckBox>
+#include <DScrollArea>
+#include <QScrollBar>
+#include <QtMath>
+#include <QFloat16>
 
 
 //#include <DGioFileInfo>
@@ -137,7 +141,15 @@ public:
         QHBoxLayout *hLay = new QHBoxLayout;
         hLay->setContentsMargins(0, 0, 0, 0);
         hLay->setSpacing(0);
-        hLay->addWidget(_toolManager);
+
+        _leftScrollArea = new DScrollArea(_borad);
+        _leftScrollArea->setFixedWidth(68);//设置比工具栏宽10
+        _leftScrollArea->setWidgetResizable(true);
+        _leftScrollArea->setWidget(_toolManager);
+        _leftScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+        hLay->addWidget(_leftScrollArea);
+        //_borad->installEventFilter(_leftScrollArea);
+        _leftScrollArea->installEventFilter(_borad);
 
         QVBoxLayout *subVLay = new QVBoxLayout;
         subVLay->setContentsMargins(0, 0, 0, 0);
@@ -180,34 +192,7 @@ public:
         dialog.exec();
         return dialog.resultFile();
     }
-//    QString execCheckLoadingFileToSupName(const QString &file)
-//    {
-//        QString legeFile = FileHander::toLegalFile(file);
 
-//        if (legeFile.isEmpty()) {
-//            //mean file not exist.
-//            MessageDlg::execMessage(tr("The file does not exist"), ENormalMsg);
-//        } else {
-//            QFileInfo info(legeFile);
-//            QString infoName = info.fileName();
-//            QFontMetrics font(_topTabs->font());
-//            infoName = font.elidedText(infoName, Qt::ElideMiddle, 200);//返回一个带有省略号的字符串
-
-//            if (info.isFile()) {
-//                const QString suffix = info.suffix().toLower();
-//                if (FileHander::supPictureSuffix().contains(suffix) || FileHander::supDdfStuffix().contains(suffix)) {
-//                    if (!info.isReadable()) {
-//                        MessageDlg::execMessage(tr("Unable to open the write-only file \"%1\"").arg(infoName), ENormalMsg);
-//                    } else {
-//                        return legeFile;
-//                    }
-//                } else {
-//                    MessageDlg::execMessage(tr("Unable to open \"%1\", unsupported file format").arg(infoName), ENormalMsg);
-//                }
-//            }
-//        }
-//        return "";
-//    }
     void addPageHelper(Page *page)
     {
         _stackWidget->addWidget(page);
@@ -265,9 +250,12 @@ private:
     ProgressLayout *_dialog = nullptr;
 
     CExportImageDialog *_exportImageDialog = nullptr;
+    DScrollArea *_leftScrollArea = nullptr;
+    QPoint      _frontMousePos;
 
     int  _touchEnchValue = 7;
     bool _autoClose = false;
+    bool _mouseClicked = false;
 
     static QList<DrawBoard *> s_boards;
 
@@ -665,11 +653,6 @@ void Page::setDrawCursor(const QCursor &cursor)
     view()->viewport()->setCursor(cursor);
 }
 
-//QCursor Page::drawCursor() const
-//{
-//    return view()->viewport()->cursor();
-//}
-
 void Page::blockSettingDrawCursor(bool b)
 {
     d_pri()->_blockSettingDrawCursor = b;
@@ -800,87 +783,7 @@ DrawBoard::DrawBoard(QWidget *parent): DWidget(parent)
 
     //file hander init
     _fileHander = new FileHander(this);
-//    connect(_fileHander, &FilePageHander::loadBegin, this, [ = ]() {
-//        d_pri()->processDialog()->setText(tr("Opening..."));
-//        d_pri()->processDialog()->exec();
-//    });
-//    connect(_fileHander, &FilePageHander::loadUpdate, this, [ = ](int process, int total) {
-//        d_pri()->processDialog()->setProcess(process, total);
-//        qApp->processEvents();
-//    });
-//    connect(_fileHander, QOverload<PageContext *, const QString &, const int>::of(&FilePageHander::loadEnd),
-//    this, [ = ](PageContext * cxt, const QString & error, const int messageType) {
-//        d_pri()->processDialog()->close();
-//        if (error.isEmpty() && messageType == 0) {
-//            if (cxt != nullptr)
-//                addPage(cxt);
-//            this->activateWindow();
-//        } else {
-//            if (cxt != nullptr)
-//                cxt->deleteLater();
-//            if (messageType != 1) {
-//                exeMessage(error, EWarningMsg, false);
-//            }
-//            d_pri()->checkClose();
-//        }
-//    });
-//    connect(_fileHander, QOverload<QImage, const QString &>::of(&FilePageHander::loadEnd),
-//    this, [ = ](QImage img, const QString & error) {
-//        d_pri()->processDialog()->close();
-//        if (!error.isEmpty()) {
-//            exeMessage(error, EWarningMsg, false);
-//            d_pri()->checkClose();
-//        } else {
-//            if (currentPage() != nullptr) {
-//                if (!img.isNull()) {
-//                    auto pos = currentPage()->context()->pageRect().center() - img.rect().center();
-//                    currentPage()->context()->scene()->clearSelectGroup();
-//                    currentPage()->context()->addImage(img, pos, true, true);
 
-//                    currentPage()->setCurrentTool(selection);
-//                    this->activateWindow();
-//                }
-//            } else {
-//                if (count() == 0) {
-//                    PageContext *cxt = new PageContext;
-//                    cxt->addImage(img);
-//                    addPage(cxt);
-//                }
-//            }
-//        }
-//    });
-
-//    connect(_fileHander, &FilePageHander::saveBegin, this, [ = ](PageContext * cxt) {
-//        fileWatcher()->removePath(cxt->file());
-//        d_pri()->processDialog()->setText(tr("Saving..."));
-//        d_pri()->processDialog()->exec();
-//    });
-//    connect(_fileHander, &FilePageHander::saveUpdate, this, [ = ](PageContext * cxt, int process, int total) {
-//        d_pri()->processDialog()->setProcess(process, total);
-//    });
-//    connect(_fileHander, &FilePageHander::saveEnd,
-//    this, [ = ](PageContext * cxt, const QString & error, const QImage & resultImg) {
-//        Q_UNUSED(resultImg)
-//        fileWatcher()->addWather(cxt->file());
-//        d_pri()->processDialog()->close();
-
-//        if (error.isEmpty())
-//            cxt->setDirty(false);
-//        else {
-//            //交互提示
-//            int ret = exeMessage(error, EWarningMsg, false);
-//            if (ret == 0) {
-//                if (resultImg.isNull()) {
-//                    //save error(find can't write),then should change path to retry again.
-//                    auto file = d_pri()->execFileSelectDialog(cxt->file());
-//                    if (!file.isEmpty())
-//                        cxt->save(file);
-//                }
-//            }
-//        }
-
-//        this->activateWindow();
-//    });
     connect(_fileHander, &FileHander::progressBegin, this, [ = ](const QString & describe) {
         d_pri()->processDialog()->reset();
         d_pri()->processDialog()->showInCenter(this);
@@ -913,20 +816,6 @@ DrawBoard::DrawBoard(QWidget *parent): DWidget(parent)
 
     qApp->installEventFilter(this);
 
-
-//    connect(qApp, &QApplication::focusChanged, this, [ = ](QWidget * old, QWidget * now) {
-//        static bool b = false;
-//        if (b)
-//            return;
-//        if (d_pri()->isFocusFriendWgt(old)) {
-//            if (!d_pri()->isFocusFriendWgt(now)) {
-//                b = true;
-//                currentPage()->view()->setFocus();
-//                currentPage()->view()->captureFocus();
-//                b = false;
-//            }
-//        }
-//    });
 }
 
 DrawBoard::~DrawBoard()
@@ -1017,11 +906,6 @@ Page *DrawBoard::nextPage(Page *page) const
     return this->page(key);
 }
 
-//Page *DrawBoard::endPage() const
-//{
-//    return page(count() - 1);
-//}
-
 int DrawBoard::count() const
 {
     return d_pri()->_stackWidget->count();
@@ -1097,16 +981,6 @@ void DrawBoard::setPageName(Page *page, const QString &name)
     setPageTitle(page, page->title());
 }
 
-//QString DrawBoard::pageName(Page *page) const
-//{
-//    return page->name();
-//}
-
-//QString DrawBoard::pageTitle(Page *page) const
-//{
-//    return page->title();
-//}
-
 void DrawBoard::setPageTitle(Page *page, const QString &title)
 {
     auto tabIndex = d_pri()->_topTabs->index(page->key());
@@ -1360,35 +1234,6 @@ bool DrawBoard::load(const QString &file)
     return ret;
 }
 
-//bool DrawBoard::loadImage(const QString &file)
-//{
-//    auto filePath = d_pri()->execCheckLoadingFileToSupName(file);
-
-//    if (filePath.isEmpty())
-//        return false;
-
-
-//    QImage img = _fileHander->loadImage(filePath);
-//    auto page = currentPage();
-//    if (page == nullptr) {
-//        page = addPage(img);
-//        setCurrentPage(page);
-//    } else {
-//        page->context()->addImage(img);
-//    }
-
-//    return !img.isNull();
-//}
-
-//bool DrawBoard::savePage(Page *page)
-//{
-//    if (page != nullptr) {
-//        return page->save();
-//    }
-
-//    return false;
-//}
-
 FileHander *DrawBoard::fileHander() const
 {
     return _fileHander;
@@ -1448,34 +1293,6 @@ bool DrawBoard::isAutoClose() const
 {
     return d_pri()->_autoClose;
 }
-//int DrawBoard::exeMessage(const QString &message,
-//                          EMessageType msgTp,
-//                          bool autoFitDialogWidth,
-//                          const QStringList &moreBtns,
-//                          const QList<int> &btnType)
-//{
-
-//    return execMessage(SMessage(message, msgTp, moreBtns, btnType));
-//}
-
-//int DrawBoard::execMessage(const SMessage &message)
-//{
-//    auto widgets = DrawBoard_private::s_boards;
-//    int limitTextLenth = widgets.isEmpty() ? 1920 : widgets.first()->width();
-//    MessageDlg dia(widgets.isEmpty() ? nullptr : widgets.first());
-//    dia.setMinimumSize(403, 163);
-//    dia.setModal(true);
-
-//    auto showText = QFontMetrics(dia.font()).elidedText(message.message, Qt::ElideRight, limitTextLenth);
-
-//    SMessage finalMessage =  message;
-//    finalMessage.message = showText;
-//    dia.setMessage(finalMessage);
-
-//    int ret = dia.exec();
-
-//    return ret;
-//}
 
 void DrawBoard::dragEnterEvent(QDragEnterEvent *e)
 {
@@ -1605,7 +1422,44 @@ bool DrawBoard::eventFilter(QObject *o, QEvent *e)
                 return true;
             }
         }
+    } else if (e->type() == QEvent::FocusIn) {
+        static bool sss = false;
+        if (currentPage() != nullptr && o == currentPage()->view() && !sss) {
+            if (currentPage()->view()->activeProxWidget() != nullptr) {
+                sss = true;
+                currentPage()->view()->setFocus();
+                currentPage()->view()->activeProxWidget()->setFocus();
+                sss = false;
+                return true;
+            }
+        }
+    } else if (e->type() == QEvent::MouseButtonPress) {
+        QMouseEvent *event = dynamic_cast<QMouseEvent *>(e);
+        QPoint currentPos = d_pri()->_toolManager->mapFromGlobal(event->globalPos());
+        if (event->button() == Qt::LeftButton && nullptr !=  d_pri()->_toolManager && d_pri()->_toolManager->rect().contains(currentPos)) {
+            auto child = d_pri()->_toolManager->childAt(currentPos);
+            auto pTool = dynamic_cast<DToolButton *>(child);
+            //点击位置不能在工具按钮上
+            if (nullptr == pTool) {
+                d_pri()->_mouseClicked  = true;
+                d_pri()->_frontMousePos = currentPos;
+            }
+        }
+    } else if (e->type() == QEvent::MouseMove && d_pri()->_mouseClicked) {
+        QMouseEvent *event = dynamic_cast<QMouseEvent *>(e);
+        int hOffset = (event->pos() - d_pri()->_frontMousePos).y();
+        QScrollBar *scrollbar =  d_pri()->_leftScrollArea->verticalScrollBar();
+        int verValue = scrollbar->value() + hOffset;
+        scrollbar->setValue(qMin(qMax(scrollbar->minimum(), verValue), scrollbar->maximum()));
+        d_pri()->_frontMousePos = event->pos();
+
+    } else if (e->type() == QEvent::MouseButtonRelease) {
+        QMouseEvent *event = dynamic_cast<QMouseEvent *>(e);
+        if (event->button() == Qt::LeftButton) {
+            d_pri()->_mouseClicked  = false;
+        }
     }
+
     return DWidget::eventFilter(o, e);
 }
 
