@@ -39,6 +39,19 @@ CUndoRedoCommand::CUndoRedoCommand()
 
 void CUndoRedoCommand::clearCommand()
 {
+    for (int i = 0; i < s_recordedCmdInfoList.size(); ++i) {
+        SCommandInfoCouple cmdInfo = s_recordedCmdInfoList[i];
+
+        CUndoRedoCommand *Cmd = getCmdByCmdInfo(cmdInfo);
+
+        if (Cmd != nullptr) {
+            if (!cmdInfo.undoInfo.vars.isEmpty())
+                Cmd->setVar(cmdInfo.undoInfo.vars, UndoVar);
+            if (!cmdInfo.redoInfo.vars.isEmpty())
+                Cmd->setVar(cmdInfo.redoInfo.vars, RedoVar);
+            delete Cmd;
+        }
+    }
     s_recordedCmdInfoList.clear();
     s_forFindCoupleMap.clear();
 }
@@ -52,7 +65,6 @@ void CUndoRedoCommand::pushStack(CUndoRedoCommand *pCmd)
 void CUndoRedoCommand::finishRecord(bool doRedoCmd)
 {
     //所有的CmdInfo组成了这样的一个单元操作
-
     if (!s_recordedCmdInfoList.isEmpty()) {
         CUndoRedoCommandGroup *pGropCmd = new CUndoRedoCommandGroup;
         for (int i = 0; i < s_recordedCmdInfoList.size();) {
@@ -80,10 +92,17 @@ void CUndoRedoCommand::finishRecord(bool doRedoCmd)
         setBlockRedoWhenPushedToStack(false);
 
         //执行完后清理操作
-        clearCommand();
+        //clearCommand();
+        s_recordedCmdInfoList.clear();
+        s_forFindCoupleMap.clear();
     }
 }
 
+bool CUndoRedoCommand::isRecordEmpty()
+{
+    return s_recordedCmdInfoList.isEmpty();
+}
+
 void CUndoRedoCommand::recordUndoCommand(CUndoRedoCommand::EDrawUndoCmdType tp,
                                          int expendTp,
                                          const QList<QVariant> &datas,
@@ -99,7 +118,6 @@ void CUndoRedoCommand::recordUndoCommand(CUndoRedoCommand::EDrawUndoCmdType tp,
     if (init) {
         clearCommand();
     }
-
     SCommandInfo undoCmd;
     undoCmd.tp = tp;
     undoCmd.expTp = expendTp;
@@ -140,6 +158,20 @@ void CUndoRedoCommand::recordRedoCommand(CUndoRedoCommand::EDrawUndoCmdType tp,
             cp.redoInfo = reDocmd;
             return;
         }
+    } else {
+        SCommandInfo undoCmd;
+        undoCmd.tp = tp;
+        undoCmd.expTp = expendTp;
+        undoCmd.urFlag = UndoVar;
+        undoCmd.vars = datas;
+
+        SCommandInfoCouple cp;
+        cp.undoInfo = undoCmd;
+        auto cmd = getCmdByCmdInfo(cp);
+        if (cmd != nullptr) {
+            cmd->parsingVars(undoCmd.vars, UndoVar);
+            delete cmd;
+        }
     }
     qWarning() << "undo redo command not match to a pair !!!!";
 }
@@ -193,6 +225,7 @@ void CUndoRedoCommand::parsingVars(const QList<QVariant> &vars, EVarUndoOrRedo v
     Q_UNUSED(varTp)
 }
 
+
 void CUndoRedoCommand::setUndoRedoStack(QUndoStack *stack, void *pGraphicsView)
 {
     s_undoStacks.insert(pGraphicsView, stack);
@@ -267,6 +300,9 @@ bool CUndoRedoCommandGroup::addCommand(const SCommandInfoCouple &pCmd)
     }
     if (ret)
         addCommand(Cmd);
+    else {
+        delete Cmd;
+    }
 
     return ret;
 }
@@ -275,14 +311,14 @@ void CUndoRedoCommandGroup::noticeUser(EVarUndoOrRedo tp)
 {
     if (_noticeOnfinished) {
         QList<CGraphicsItem *> bzItems;
-        CDrawScene *pScene = nullptr;
+        PageScene *pScene = nullptr;
         for (CUndoRedoCommand *pCmd : _allCmds) {
             CItemUndoRedoCommand *pItemCmd = dynamic_cast<CItemUndoRedoCommand *>(pCmd);
             if (pItemCmd != nullptr) {
                 if (!pItemCmd->isNoNeedSelected(tp)) {
                     QGraphicsItem *pItem = pItemCmd->item();
                     if (pScene == nullptr) {
-                        pScene = qobject_cast<CDrawScene *>(pItem->scene());
+                        pScene = qobject_cast<PageScene *>(pItem->scene());
                     }
 
                     CGraphicsItem *pBzItem = dynamic_cast<CGraphicsItem *>(pItem);
@@ -293,7 +329,7 @@ void CUndoRedoCommandGroup::noticeUser(EVarUndoOrRedo tp)
             } else {
                 CSceneUndoRedoCommand *pSceneCmd = dynamic_cast<CSceneUndoRedoCommand *>(pCmd);
                 if (pScene == nullptr) {
-                    pScene = qobject_cast<CDrawScene *>(pSceneCmd->scene());
+                    pScene = qobject_cast<PageScene *>(pSceneCmd->scene());
                 }
 
                 bool finished = false;
@@ -333,19 +369,6 @@ void CUndoRedoCommandGroup::noticeUser(EVarUndoOrRedo tp)
             for (CGraphicsItem *pBzItem : bzItems) {
                 pScene->selectItem(pBzItem->thisBzProxyItem(true));
             }
-
-
-            //如果处于非选择工具下(比如模糊工具下),那么需要判断当前的情况是否支持保持当前工具
-            auto view = CManageViewSigleton::GetInstance()->getCurView();
-            auto toolModle = CManageViewSigleton::GetInstance()->getCurScene()->getDrawParam()->getCurrentDrawToolMode();
-            if (toolModle != selection) {
-                if (!drawApp->isViewToolEnable(view, toolModle)) {
-                    drawApp->setViewCurrentTool(view, selection);
-                } else {
-                    drawApp->setViewCurrentTool(view, toolModle);
-                }
-            }
-            pScene->refreshLook();
         }
     }
 }
@@ -485,9 +508,9 @@ QGraphicsScene *CSceneUndoRedoCommand::scene()
     return _scene;
 }
 
-CDrawScene *CSceneUndoRedoCommand::drawScene()
+PageScene *CSceneUndoRedoCommand::drawScene()
 {
-    return qobject_cast<CDrawScene *>(_scene);
+    return qobject_cast<PageScene *>(_scene);
 }
 
 CSceneUndoRedoCommand::EChangedType CSceneUndoRedoCommand::tp()
@@ -533,6 +556,10 @@ CSceneItemNumChangedCommand::CSceneItemNumChangedCommand(EChangedType tp)
 {
 }
 
+CSceneItemNumChangedCommand::~CSceneItemNumChangedCommand()
+{
+}
+
 void CSceneItemNumChangedCommand::parsingVars(const QList<QVariant> &vars, EVarUndoOrRedo varTp)
 {
     CSceneUndoRedoCommand::parsingVars(vars, varTp);
@@ -569,13 +596,13 @@ void CSceneItemNumChangedCommand::real_redo()
     if (_changedTp == Removed) {
         if (scene() != nullptr) {
             for (int i = 0; i < _Items.size(); ++i) {
-                scene()->removeItem(_Items[i]);
+                drawScene()->removeCItem(_Items[i]);
             }
         }
     } else {
         if (scene() != nullptr) {
             for (int i = 0; i < _Items.size(); ++i) {
-                scene()->addItem(_Items[i]);
+                drawScene()->addCItem(_Items[i], false);
             }
         }
     }
@@ -669,13 +696,13 @@ void CSceneBoundingChangedCommand::real_redo()
     }
 }
 
-CCmdBlock::CCmdBlock(CDrawScene *pScene, CSceneUndoRedoCommand::EChangedType EchangedTp, QGraphicsItem *pItem, bool doRedo):
+CCmdBlock::CCmdBlock(PageScene *pScene, CSceneUndoRedoCommand::EChangedType EchangedTp, QGraphicsItem *pItem, bool doRedo):
     CCmdBlock(pScene, EchangedTp, QList<QGraphicsItem *>() << pItem, doRedo)
 {
 
 }
 
-CCmdBlock::CCmdBlock(CDrawScene *pScene, CSceneUndoRedoCommand::EChangedType EchangedTp,
+CCmdBlock::CCmdBlock(PageScene *pScene, CSceneUndoRedoCommand::EChangedType EchangedTp,
                      const QList<QGraphicsItem *> &list, bool doRedo)
     : _doRedo(doRedo), _pScene(pScene), _scenChangedType(EchangedTp)
 {
@@ -821,11 +848,13 @@ CCmdBlock::~CCmdBlock()
     }
 }
 
-
 CSceneGroupChangedCommand::CSceneGroupChangedCommand():
     CSceneUndoRedoCommand(EGroupChanged)
 {
+}
 
+CSceneGroupChangedCommand::~CSceneGroupChangedCommand()
+{
 }
 
 void CSceneGroupChangedCommand::parsingVars(const QList<QVariant> &vars, EVarUndoOrRedo varTp)
@@ -840,7 +869,7 @@ void CSceneGroupChangedCommand::parsingVars(const QList<QVariant> &vars, EVarUnd
     }
 
     //获取到当前组合的情况
-    _inf[varTp] = vars[1].value<CDrawScene::CGroupBzItemsTree>();
+    _inf[varTp] = vars[1].value<PageScene::CGroupBzItemsTree>();
 
 
     //是否能解析的判断
@@ -863,15 +892,19 @@ void CSceneGroupChangedCommand::parsingVars(const QList<QVariant> &vars, EVarUnd
 void CSceneGroupChangedCommand::real_undo()
 {
     CGraphicsItemGroup *pGroup = drawScene()->loadGroupTree(_inf[UndoVar]);
-    if (pGroup != nullptr)
+    if (pGroup != nullptr && pGroup->groupType() == CGraphicsItemGroup::EVirRootGroup) {
         drawScene()->cancelGroup(pGroup);
+        delete pGroup;
+    }
     qDebug() << "scene group info = " << drawScene()->bzGroups().count();
 }
 
 void CSceneGroupChangedCommand::real_redo()
 {
     CGraphicsItemGroup *pGroup = drawScene()->loadGroupTree(_inf[RedoVar]);
-    if (pGroup != nullptr)
+    if (pGroup != nullptr && pGroup->groupType() == CGraphicsItemGroup::EVirRootGroup) {
         drawScene()->cancelGroup(pGroup);
+        delete pGroup;
+    }
     qDebug() << "scene group info = " << drawScene()->bzGroups().count();
 }
