@@ -23,7 +23,7 @@
 
 #include "dialog.h"
 
-class CCutDialog : public Dialog
+class CCutDialog : public DDialog
 {
     Q_OBJECT
 public:
@@ -41,8 +41,12 @@ public:
     */
     CutStatus getCutStatus();
 
+
+    int exec() override;
+
 protected:
     void keyPressEvent(QKeyEvent *e) override;
+    void showEvent(QShowEvent *event) override;
 private:
     CutStatus m_cutStatus;
 };
