@@ -66,17 +66,6 @@ CExportImageDialog::~CExportImageDialog()
     delete _pPrivate;
 }
 
-//void CExportImageDialog::setSupImageSuffix(const QStringList &suffixs)
-//{
-//    m_formatCombox->clear();
-//    foreach (auto suffix, suffixs) {
-//        if (!suffix.isEmpty()) {
-//            m_formatCombox->addItem(suffix.toLower());
-//        }
-//    }
-//}
-
-
 int CExportImageDialog::getImageType() const
 {
     return  m_formatCombox->currentIndex();
@@ -157,25 +146,17 @@ QSize CExportImageDialog::desImageSize() const
 void CExportImageDialog::initUI()
 {
     setWgtAccesibleName(this, "Export dialog");
-    //setFixedSize(DIALOG_SIZE);
     resize(DIALOG_SIZE);
     setModal(true);
 
     setContentsMargins(0, 0, 0, 0);
 
-    CSvgLabel *logoLable = new CSvgLabel(":/theme/common/images/logo.svg", this);
-    logoLable->setFixedSize(QSize(32, 32));
-
-
-    logoLable->move(10, 9);
-    logoLable->setAlignment(Qt::AlignLeft);
-
+    setIcon(QIcon::fromTheme("deepin-draw"));
     setWindowTitle(tr("Export"));
 
 
     m_fileNameEdit = new DLineEdit(this);
     setWgtAccesibleName(m_fileNameEdit, "Export name line editor");
-    //m_fileNameEdit->setFixedSize(LINE_EDIT_SIZE);
     m_fileNameEdit->setFixedHeight(LINE_EDIT_SIZE.height());
     m_fileNameEdit->setClearButtonEnabled(false);
     //编译器会对反斜杠进行转换，要想在正则表达式中包括一个\，需要输入两次，例如\\s。要想匹配反斜杠本身，需要输入4次，比如\\\\。
@@ -192,8 +173,6 @@ void CExportImageDialog::initUI()
         m_savePathCombox->insertItem(Music, tr("Music"));
         m_savePathCombox->insertItem(UsrSelect, tr("Select other directories"));
     }
-    //m_savePathCombox->setFixedSize(LINE_EDIT_SIZE);
-
 
     m_savePathCombox->/*setFixedSize*/setFixedHeight(LINE_EDIT_SIZE.height());
     m_savePathCombox->hide();
@@ -230,13 +209,6 @@ void CExportImageDialog::initUI()
     writeableFormats.removeAt(0);
     m_formatCombox->addItems(writeableFormats);
 
-//    m_formatCombox->insertItem(JPG, tr("jpg"));
-//    m_formatCombox->insertItem(PNG, tr("png"));
-//    m_formatCombox->insertItem(BMP, tr("bmp"));
-//    m_formatCombox->insertItem(TIF, tr("tif"));
-//    m_formatCombox->insertItem(PDF, tr("pdf"));
-    //m_formatCombox->setFixedSize(LINE_EDIT_SIZE);
-
     m_formatCombox->setFixedHeight(LINE_EDIT_SIZE.height());
 
     m_qualitySlider = new DSlider(Qt::Horizontal, this);
@@ -286,21 +258,12 @@ void CExportImageDialog::initConnection()
 {
     connect(m_savePathCombox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotOnSavePathChange(int)), Qt::QueuedConnection);
     connect(m_formatCombox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotOnFormatChange(int)));
-    //connect(this, &DDialog::buttonClicked, this, &CExportImageDialog::execCheckFile);
     connect(m_qualitySlider, SIGNAL(valueChanged(int)), this, SLOT(slotOnQualityChanged(int)));
-    //connect(m_questionDialog, &DDialog::buttonClicked, this, &CExportImageDialog::slotOnQuestionDialogButtonClick);
 
     //设置的文件名为空时应该要设置保存按钮为disable
     connect(m_fileNameEdit, &DLineEdit::textChanged, this, [ = ](const QString & text) {
 
         QString newText = text;
-
-        //        newText.remove(dApp->fileNameRegExp());
-
-        //        m_fileNameEdit->blockSignals(true);
-        //        m_fileNameEdit->setText(newText);
-        //        m_fileNameEdit->blockSignals(false);
-
         bool isEmpty = newText.isEmpty();
 
         if (m_saveBtnId != -1) {
@@ -357,21 +320,6 @@ void CExportImageDialog::slotOnSavePathChange(int index)
 
 void CExportImageDialog::slotOnFormatChange(int index)
 {
-//    switch (index) {
-//    case PDF:
-//    case BMP:
-//    case TIF:
-//        m_qualitySlider->setValue(100);
-//        m_qualitySlider->setEnabled(false);
-//        break;
-//    case JPG:
-//    case PNG:
-//        m_qualitySlider->setEnabled(true);
-//        break;
-//    default:
-//        break;
-//    }
-
     if (exportFormatMapping.find(index) != exportFormatMapping.end()) {
         m_saveFormat = exportFormatMapping[index];
     } else {
@@ -395,14 +343,6 @@ int CExportImageDialog::execCheckFile(const QString &text)
     //  [BUG: 30843] 希望在导出时，名字以点开头的图片，也能给到提示：以点开始会被隐藏
     QString fileName = m_fileNameEdit->text().trimmed();
     if (fileName.startsWith(".")) {
-//        MessageDlg dialog(this);
-//        dialog.setModal(true);
-//        dialog.setIcon(QPixmap(":/icons/deepin/builtin/Bullet_window_warning.svg"));
-//        dialog.setMessage(tr("This file will be hidden if the file name starts with a dot (.). Do you want to hide it?"));
-//        dialog.addButton(tr("Cancel"), false, DDialog::ButtonNormal);
-//        dialog.addButton(tr("Confirm"), true, DDialog::ButtonRecommend);
-//        dialog.showInCenter(this);
-//        int status = dialog.exec();
         int status = MessageDlg::execMessage(tr("This file will be hidden if the file name starts with a dot (.). Do you want to hide it?"), EWarningMsg,
                                              QStringList() << tr("Cancel") << tr("Confirm"),
                                              QList<EButtonType>() << ENormalMsgBtn << EWarningMsgBtn, this);
@@ -507,16 +447,6 @@ int CExportImageDialog::execFileIsExists(const QString &path)
     return m_questionDialog->exec();
 }
 
-//bool CExportImageDialog::isHaveSuffix(const QString &src)
-//{
-//    bool flag = false;
-//    if (src.endsWith(".jpg") || src.endsWith(".png") || src.endsWith(".bmp")
-//            || src.endsWith(".tif") || src.endsWith(".pdf")) {
-//        flag = true;
-//    }
-//    return flag;
-//}
-
 QString CExportImageDialog::getCompleteSavePath() const
 {
     QString fileName = m_fileNameEdit->text().trimmed();
@@ -551,7 +481,6 @@ void CExportImageDialog::CExportImageDialog_private::initSizeSettingLayoutUi(QFo
     spinBox->setSpinRange(0, 999999);
     spinBox->lineEdit()->setValidator(new CIntValidator(0, 999999, spinBox));
     spinBox->setEnabledEmbedStyle(true);
-    //spinBox->setSuffix("%");
     spinBox->setButtonSymbols(QAbstractSpinBox::UpDownArrows);
     spinBox->setMaximumSize(QSize(100, 36));
     _radioSpinBox = spinBox;
