@@ -1,21 +1,27 @@
 QTEST_FUNCTION_TIMEOUT=500000
-QT_QPA_PLATFORM=offscreen
+export QT_QPA_PLATFORM='offscreen'
 cd ../
 [ -d build-ut ] && rm -fr build-ut || mkdir build-ut
 [ -d build ] && rm -fr build 
 mkdir -p build
 cp tests/collection-coverage.sh build/
 cd build/
-cmake ../tests/
-#make test -j8
+
+cmake -S ../ -B ./ -DDEEPINDRAW_TEST=ON
+
 make -j8
 
-lcov --directory ./CMakeFiles/deepin-draw-test.dir/ --zerocounters
-./deepin-draw-test
-#第一次会因为未知原因失败
+lcov --directory ./src/CMakeFiles/deepinDrawBase.dir/ --zerocounters
+
+# run test
+ASAN_OPTIONS="fast_unwind_on_malloc=1" ./tests/deepin-draw-test
+
+#first to collection (unknowed fail may happen).
 ./collection-coverage.sh
+
 sleep 5
-#第一次因为未知原因失败,执行第二次进行收集
+
+#unknowed failed may happen,so we collect again.
 ./collection-coverage.sh
 
 cd ../
